@@ -224,8 +224,16 @@ class Connection(object):
         while True:
             try:
                 logger.debug('Issuing %s request to: %s' % (method, str(urlpath)))
-                logger.debug('Values are: \n headers: {0} \n body: {1}'.format(headers, body))
+                if body is not None and '"password":' in repr(body):
+                    clean_body = '<username and password hidden>'
+                    self.conn.set_debuglevel(0)
+                else:
+                    clean_body = body
+                logger.debug('Values are: \n headers: {0} \n body: {1}'.format(headers, clean_body))
                 self.conn.request(method, urlpath, body=body, headers=headers)
+
+                # reset debug level
+                self.conn.set_debuglevel(self.HTTPLIB_DEBUGLEVEL)
                 resp = self.conn.getresponse()
                 return resp
                 
@@ -444,29 +452,7 @@ class Connection(object):
 
         return json.loads(data, object_hook=DictObject.create_from_dict)
 
-    def upload_file(self, urlpath, data, params=None, extra_headers=None):
-        '''Send a JSON rquest to the host.  For POST/PUT requests, the
-        `data` parameter will be JSON-encoded before transmission.  For
-        all requests, the response is JSON-decoded using the
-        DictObject class before returning.'''
-
-        if extra_headers is None:
-            extra_headers = {}
-
-        extra_headers['Content-Type'] = 'application/octet-stream'
-
-        resp = self.request(urlpath, "PUT", data,
-                            params=params, extra_headers=extra_headers)
-
-        data = resp.read()
-        if resp.status == 204:
-            return # no data
-        elif resp.status == 201:
-            # created resource
-            return {'Location-Header': resp.getheader('location', '')}
-        return data
-
-    def post_raw(self, urlpath, data, params=None, extra_headers=None):
+    def upload(self, urlpath, data, method="POST", params=None, extra_headers=None):
         """Upload raw data to the given URL path with the given content type.
 
         `data` may be either a string or a python file object.
@@ -477,10 +463,13 @@ class Connection(object):
         `params` is a dictionary of URL parameters to attach to the request.
             The keys and values will be urlencoded.
 
+        `method` defaults to "POST", but can be overridden if the API requires another
+            method such as "PUT" to be used instead.
+
         Returns location information if resource has been created,
         otherwise the response body (if any).
         """
-        resp = self.request(urlpath, "POST", data, params=params,
+        resp = self.request(urlpath, method, data, params=params,
                             extra_headers=extra_headers)
         data = resp.read()
         if resp.status == 204:
@@ -501,10 +490,12 @@ class Connection(object):
             - a complete path
             - a directory
 
-        In the first case the file will have the specified name and extension. In the second case the filename will be retrieved by the 'Content-Disposition' HTTP header.
+        In the first case the file will have the specified name and extension. In the second case
+        the filename will be retrieved by the 'Content-Disposition' HTTP header.
         If a path cannot be determined, a ValueError is raised.
 
-        `overwrite` if True will save the downloaded file to `path` no matter if the file already exists.
+        `overwrite` if True will save the downloaded file to `path` no matter if the file
+                    already exists.
         
         `method` is the HTTP method used for the request.
         
@@ -517,13 +508,13 @@ class Connection(object):
 
         # try to determine the filename
         if path is None:
-            #we didn't got a path from, create a temp directory to 
+            # we didn't got a path from, create a temp directory to
             # store the file
             directory = tempfile.mkdtemp()
         else:
             # we got a path which is a directory maybe, check that it's valid
             if os.path.isdir(path):
-                #it's valid, we have a directory to store the file in
+                # it's valid, we have a directory to store the file in
                 directory = path
             elif path[-1] == os.sep:
                 # we got a path which is a directory that doesn't exists
@@ -541,7 +532,8 @@ class Connection(object):
             filename = resp.getheader('Content-Disposition').split('=')[1]
 
         if not filename:
-            raise ValueError("{0} is not a valid path. Specify a full path for the file to be created".format(path))
+            raise ValueError("{0} is not a valid path. "
+                             "Specify a full path for the file to be created".format(path))
         # Compose the path
         path = os.path.join(directory, filename)
 
