@@ -5,15 +5,15 @@
 #   https://github.com/riverbed/flyscript/blob/master/LICENSE ("License").  
 # This software is distributed "AS IS" as set forth in the License.
 
-
 from rvbd.common.app import Application
 import rvbd.shark
 
+
 class SharkApp(Application):
     """Simple class to wrap common command line parsing"""
     def __init__(self, *args, **kwargs):
         super(SharkApp, self).__init__(*args, **kwargs)
-        self.optparse.set_usage('%prog SHARK')
+        self.optparse.set_usage('%prog SHARK_HOSTNAME <options>')
         self.shark = None
 
     def parse_args(self):
@@ -24,7 +24,6 @@ class SharkApp(Application):
                                       auth=self.auth,
                                       force_version=self.options.api_version)
 
-
     def validate_args(self):
         if len(self.args) < 1:
-            self.optparse.error('missing SHARK hostname')
+            self.optparse.error('missing SHARK_HOSTNAME')
